package com.gentics.portalnode.sdk.filter;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import com.gentics.api.lib.etc.ObjectTransformer;
import com.gentics.api.lib.expressionparser.EvaluationException;
import com.gentics.api.lib.expressionparser.filtergenerator.PostProcessor;
import com.gentics.api.lib.resolving.Resolvable;

/**
 * Post Processor for sorting objects
 * Usage: filter([rule], 'com.gentics.portalnode.sdk.filter.Sorter', 'firstname')
 */
public class Sorter implements PostProcessor {
	/* (non-Javadoc)
	 * @see com.gentics.api.lib.expressionparser.filtergenerator.PostProcessor#process(java.util.Collection, java.lang.Object)
	 */
	public void process(List<Resolvable> resolvables, Object data)
			throws EvaluationException {
		String sortBy = ObjectTransformer.getString(data, "firstname");
		Collections.sort(resolvables, new AttributeComparator(sortBy));
	}

	/**
	 * Attribute comparator
	 */
	protected class AttributeComparator implements Comparator<Resolvable> {
		/**
		 * Name of the attribute to sort
		 */
		protected String attributeName;

		/**
		 * Create an instance
		 * @param attributeName attribute name
		 */
		public AttributeComparator(String attributeName) {
			this.attributeName = attributeName;
		}

		/* (non-Javadoc)
		 * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
		 */
		public int compare(Resolvable res0, Resolvable res1) {
			return ObjectTransformer.getString(res0.get(attributeName), "")
					.compareToIgnoreCase(
							ObjectTransformer.getString(
									res1.get(attributeName), ""));
		}
	}
}
